<?php 
/**
 * fsAdmin - Admin section for Flickr-stream
 *
 * @package Flickr-stream
 * @author Dustin Scarberry
 *
 * @since 1.1.5
 */
class fsAdmin
{
	
	private $_options;
		
	public function __construct()
	{
		
		//get plugin options
		$this->_options = get_option('flickrstream_main_opts');
	
		//add hooks
		add_action('admin_init', array(&$this, 'processor'));
		add_action('admin_enqueue_scripts', array(&$this, 'addScripts'));
		add_action('admin_menu', array(&$this, 'addMenus'));
		
	}
		
	public function addMenus()
	{
			
		add_options_page('Flickr-stream Settings', 'Flickr-stream', 'manage_options', 'flickr-stream_settings', array($this, 'panels'));	
		
	}
		
	public function addScripts()
	{
		
		wp_enqueue_style('flickrstream_style', plugins_url('css/admin_style.css', __FILE__), false, null);
		wp_enqueue_script('jquery');
			
	}
	
	public function panels()
	{
	
		//declare globals
		global $wpdb;
		//reload options to be sure correct options are displayed
		$this->_options = get_option('flickrstream_main_opts');
		
	?>
		
		<div class="wrap" id="flickrstream_main_opts">
		
			<?php screen_icon('flickr-stream'); ?>
			
			<h2 id="fsMastHead">Flickr-stream Settings</h2>
			
			<script>
				
				jQuery(function(){
					
					jQuery('.fsConfirm').click(function(){
						
						if(!confirm('Are you sure you want to delete this item?'))
							return false;
						
					});
					
				});
				
			</script>
			
			<?php
			
			if(isset($_POST['createShortcode']))
			{
				
			?>
				
				<div class="fsFormBox fsTopformBox">
					<form method="post">  
						<h3><?php _e('Create Shortcode'); ?></h3>
						<p>
							<label><?php _e('Name: '); ?></label>
							<input type="text" name="vanityname"/>
							<span class="fsHint"><?php _e('ex: vanity name just for your reference'); ?></span>
						</p>
						<p>
							<label><?php _e('Type: '); ?></label>
							<select name="type">
								<option></option>
								<option>Set</option>
								<option>Gallery</option>
							</select>
							<span class="fsHint"><?php _e('ex: type of picture group'); ?></span>
						</p>
						<p>
							<label><?php _e('ID: '); ?></label>
							<input type="text" name="id"/>
							<span class="fsHint"><?php _e('ex: id of set or gallery'); ?></span>
						</p>
						<p>
							<label><?php _e('Number Of Photos: '); ?></label> 
							<select name="photocnt">
								<option></option>
								
								<?php
						
								for($i = 1; $i < 31; $i++)			
								{				
	
									echo '<option>' . $i . '</option>';	
												
								}
								
								?>
								
							</select>
							<span class="fsHint"><?php _e('ex: number of photos to display'); ?></span>
						</p>
						<p>
							<label><?php _e('Photo Selection: '); ?></label> 
							<select name="photoselect">
								<option></option>
								<option>Beginning</option>
								<option>Random</option>
							</select>
							<span class="fsHint"><?php _e('ex: how to select photos'); ?></span>
						</p>
						<p>
							<label><?php _e('Link Type: '); ?></label> 
							<select name="linktype">
								<option></option>
								<option>Image/Fancybox</option>
								<option>Flickr</option>
							</select>
							<span class="fsHint"><?php _e('ex: how to open photo links'); ?></span>
						</p>
						<p>
							<label><?php _e('Thumbnail Size: '); ?></label>
							<select name="thumbsize">
								<option></option>
								<option>Small</option>
								<option>Medium</option>
							</select>
							<span class="fsHint"><?php _e('ex: thumbnail size to use'); ?></span>
						</p>
						<p>
							<label><?php _e('Photo Alignment: '); ?></label>	
							<select name="photoAlign">
								<option></option>
								<option>Left</option>
								<option>Center</option>
								<option>Right</option>		
							</select>
							<span class="fsHint"><?php _e('ex: alignment of photos in gallery/set'); ?></span>
						</p>
						<p>
							<label><?php _e('Cache Data: '); ?></label>
							<input type="checkbox" name="cachedata"/>
						</p>
						<p>
							<label><?php _e('Hide Set/Gallery Title: '); ?></label>
							<input type="checkbox" name="hidetitle"/>
						</p>
						<p>
							<label><?php _e('Hide Captions: '); ?></label>
							<input type="checkbox" name="hidecaption"/>
						</p>						
						<p class="submit">  
							<input type="submit" name="saveShortcode" value="<?php _e('Save New Shortcode') ?>" class="button-primary"/> 
							<?php wp_nonce_field('flickrstream_save_shortcode'); ?>
							<a href="?page=flickr-stream_settings" class="fsCancel">Go Back</a>							
						</p> 
					</form>
				</div>
					
				<?php
				
			}
			elseif(isset($_POST['editShortcode']))
			{

				$data = get_option('flickrstream_short_' . $_POST['key']);
						
			?>
						
				<div class="fsFormBox fsTopformBox">
					<form method="post">  
						<h3><?php _e('Edit Shortcode'); ?></h3>
						<p>
							<label><?php _e('Name: '); ?></label>
							<input type="text" name="vanityname" value="<?php echo $data['vanityname']; ?>"/>
							<span class="fsHint"><?php _e('ex: vanity name just for your reference'); ?></span>
						</p>
						<p>
							<label><?php _e('Type: '); ?></label>
							<select name="type">
								<option></option>					

								<?php					

								$opts = array(0 => 'Set', 1 => 'Gallery');	

								foreach($opts as $value)			
								{
									
									if($value == $data['type'])	
										echo '<option selected>' . $value . '</option>';		
									else					
										echo '<option>' . $value . '</option>';		
										
								}
										
								?>	
								
							</select>
							<span class="fsHint"><?php _e('ex: type of picture group'); ?></span>
						</p>
						<p>
							<label><?php _e('ID: '); ?></label>
							<input type="text" name="id" value="<?php echo $data['id']; ?>"/>
							<span class="fsHint"><?php _e(' ex: id of set or gallery'); ?></span>
						</p>
						<p>
							<label><?php _e('Number Of Photos: '); ?></label> 
							<select name="photocnt">
								<option></option>
										
								<?php
						
								for($i = 1; $i < 31; $i++)			
								{				
										
									if($i == $data['photocnt'])
										echo '<option selected>' . $i . '</option>';
									else				
										echo '<option>' . $i . '</option>';	
												
								}
									
								?>
										
							</select>
							<span class="fsHint"><?php _e('ex: number of photos to display'); ?></span>
						</p>
						<p>
							<label><?php _e('Photo Selection: '); ?></label> 
							<select name="photoselect">
								<option></option>
									
								<?php
										
								$opts = array(0 => 'Beginning', 1 => 'Random');	

								foreach($opts as $value)
								{				
										
									if($value == $data['photoselect'])
										echo '<option selected>' . $value . '</option>';
									else					
										echo '<option>' . $value . '</option>';
												
								}
										
								?>
						
							</select>
							<span class="fsHint"><?php _e('ex: how to select photos from Flickr'); ?></span>
						</p>
						<p>
							<label><?php _e('Link Type: '); ?></label> 
							<select name="linktype">
								<option></option>
										
								<?php					

								$opts = array(0 => 'Image/Fancybox', 1 => 'Flickr');	

								foreach($opts as $value)			
								{
										
									if($value == $data['linktype'])	
										echo '<option selected>' . $value . '</option>';		
									else					
										echo '<option>' . $value . '</option>';		
										
								}
										
								?>
						
							</select>
							<span class="fsHint"><?php _e('ex: how to open photo links'); ?></span>
						</p>
						<p>
							<label><?php _e('Thumbnail Size: '); ?></label>
							<select name="thumbsize">
								<option></option>
										
								<?php
										
								$opts = array(0 => 'Small', 1 => 'Medium');
										
								foreach($opts as $value)
								{
										
									if($value == $data['thumbsize'])
										echo '<option selected>' . $value . '</option>';
									else
										echo '<option>' . $value . '</option>';
												
								}
										
								?>
										
							</select>
							<span class="fsHint"><?php _e('ex: thumbnail size to use'); ?></span>
						</p>
						<p>
							<label><?php _e('Photo Alignment: '); ?></label>	
							<select name="photoAlign">
								<option></option>
										
								<?php
										
								$opts = array(0 => 'Left', 1 => 'Center', 2 => 'Right');
										
								foreach($opts as $value)
								{
										
									if($value == $data['photoAlign'])
										echo '<option selected>' . $value . '</option>';
									else
										echo '<option>' . $value . '</option>';
												
								}
										
								?>
										
							</select>
							<span class="fsHint"><?php _e('ex: alignment of photos in gallery/set'); ?></span>
						</p>
						<p>
							<label><?php _e('Cache Data: '); ?></label>
									
							<?php
									
							if($data['cachedata'] == 'on')			
								echo '<input type="checkbox" name="cachedata" checked/>';	
							else			
								echo '<input type="checkbox" name="cachedata"/>';					
									
							?>	

						</p>
						<p>
							<label><?php _e('Hide Set/Gallery Title: '); ?></label>
									
							<?php
									
							if($data['hidetitle'] == 'on')			
								echo '<input type="checkbox" name="hidetitle" checked/>';	
							else			
								echo '<input type="checkbox" name="hidetitle"/>';					

							?>	
									
						</p>
						<p>
							<label><?php _e('Hide Captions: '); ?></label>
								
							<?php
								
							if($data['hidecaption'] == 'on')			
								echo '<input type="checkbox" name="hidecaption" checked/>';	
							else			
								echo '<input type="checkbox" name="hidecaption"/>';					
								
							?>
								
						</p>
						<p class="submit">  
							<input type="submit" name="updateShortcode" value="<?php _e('Save Changes') ?>" class="button-primary"/>
							<input type="hidden" name="shortid" value="<?php echo $data['shortid']; ?>"/>
							<?php wp_nonce_field('flickrstream_update_shortcode'); ?>
							<a href="?page=flickr-stream_settings" class="fsCancel">Go Back</a>
						</p> 
					</form>
						
					<h3><?php _e('Preview: '); ?></h3>
						
					<?php
						
					require_once 'fsworkhorse.class.php';
						
					if(!empty($data))
					{

						$content = '<div class="flickrstream_short_embed">';
							
						$workhorse = new fsWorkhorse();
						$content .= $workhorse->returnPhotos('shortcode', $data, null);

						$content .= '</div>';
							
						echo $content;
								
					}

					?>					
							
				</div>
					
			<?php	
					
			}
			else
			{
						
			?>

				<div class="fsFormBox fsTopformBox">
					<form method="post">  
						<h3>General Settings</h3>	
						<p>
							<label><?php _e('Flickr Api Key: '); ?></label>
							<input type="text" name="apikey" value="<?php echo $this->_options['apikey']; ?>"/>
							<span class="fsHint"><?php _e('ex: your api key from Flickr'); ?></span>
						</p> 
						<p>
							<label><?php _e('Include Fancybox Scripts: '); ?></label>
							<input type="checkbox" name="fancyboxInc" <?php echo ($this->_options['fancyboxInc'] == 'yes' ? 'checked' : ''); ?>/>
							<span class="fsHint"><?php _e('ex: check only if not using a fancybox plugin'); ?></span>
						</p> 
						<p>
							<label><?php _e('Include Mobile Photo Viewer: '); ?></label>
							<input type="checkbox" name="useMobileView" <?php echo ($this->_options['useMobileView'] == 'yes' ? 'checked' : ''); ?>/>
							<span class="fsHint"><?php _e('ex: check to use mobile photo viewer for mobile devices (adds about 77kb of code)'); ?></span>
						</p> 
						<p class="submit">  
							<input type="submit" name="saveopts" value="<?php _e('Save Changes') ?>" class="button-primary"/> 
							<?php wp_nonce_field('flickrstream_update_options'); ?>							
						</p> 
					</form>	
				</div>
				<div class="fsFormBox">
					<h3>Shortcodes</h3>
					<table class="widefat fixed fsTable">
						<thead>
							<tr>
								<th>Name</th>
								<th>Shortcode</th>
								<th>Last Updated</th>
								<th>Cached</th>
								<th>Actions</th>
							</tr>
						</thead>
						<tbody>
							
						<?php

						$rows = $wpdb->get_results('SELECT * FROM ' . $wpdb->prefix . 'options WHERE option_name LIKE "flickrstream_short_%" ORDER BY option_name', ARRAY_A);
							
						if(empty($rows))
						{
							
						?>
							
							<tr>
								<td colspan="5">No shortcodes found</td>
							</tr>
							
						<?php
							
						}
						else
						{
							
							foreach($rows as $value)
							{

								$data = unserialize($value['option_value']);

								?>
							
								<tr>
									<td><?php echo $data['vanityname']; ?></td>
									<td>[flickrstream id="<?php echo $data['shortid']; ?>"]</td>
									<td><?php echo date('M j, Y @ g:ia', $data['updated']); ?></td>
									<td><?php echo ($data['cachedata'] == 'on' ? 'Yes' : 'No'); ?></td>
									<td>
										<form method="post">
											<input class="fsLinkButton" type="submit" name="editShortcode" value="Edit"/>
											<input class="fsLinkButton fsConfirm" type="submit" name="delShortcode" value="Delete"/>
											<input type="hidden" name="key" value="<?php echo $data['shortid']; ?>"/>
											<?php wp_nonce_field('flickrstream_actions'); ?>
										</form>
									</td>
								</tr>
								
								<?php
							
							}
							
						}

						?>

						</tbody>
						<tfoot>
							<tr>
								<th>Name</th>
								<th>Shortcode</th>
								<th>Last Updated</th>
								<th>Cached</th>
								<th>Actions</th>
							</tr>
						</tfoot>
					</table>
					<form method="post">
						<p class="submit">
							<input class="button-secondary" type="submit" name="createShortcode" value="Create Shortcode"/>
						</p>
					</form>
				</div>
				<div class="postbox">
					<h3 class="hndle fsPostBox"><span><?php _e("FAQ's"); ?></span></h3>
					<div class="inside">
						<div class="fsFormBox">
							<ul>
								<li>You must give a <a href="http://www.flickr.com/services/apps/create/apply" target="_blank">valid Flickr Api key</a> in order for the plugin to work.</li>
								<li>When adding a set your must give its set id for the ID field (ie 72157632734875425). For a gallery, you should pass the entire url of the gallery (ie http://www.flickr.com/photos/davedunne/galleries/72157622248195017/).</li>
								<li>Uninstalling plugin will remove all data associated with it, including your api key, shortcodes and widget settings.</li>
								<li>Never set the 'number of photos option' for more photos than are in a particular set or gallery.</li>
								<li>To refresh the images of a cached widget or shortcode, simply click edit and then click on save changes.</li>
								<li>Only check the box to include Fancybox scripts if not using another Fancybox plugin.</li>
								<li>The hide captions option only affects Fancybox images, not Flickr links.</li>
								<li>Check the mobile viewer option to use Photoswipe for mobile devices</li>
							</ul>
						</div>
					</div>
				</div>	
					
			<?php
				
			}
				
			?>

		</div>
		
	<?php
		
	}
		
	public function processor()
	{

		if(!empty($_POST))
		{
	
			//SAVE MAIN OPTIONS//
			if(isset($_POST['saveopts']))
			{
			
				if(check_admin_referer('flickrstream_update_options'))
				{
				
					$opts['apikey'] = sanitize_text_field($_POST['apikey']);
					$opts['marker'] = $this->_options['marker'];	
					$opts['fancyboxInc'] = (isset($_POST['fancyboxInc']) ? 'yes' : 'no');
					$opts['useMobileView'] = (isset($_POST['useMobileView']) ? 'yes' : 'no');
					
					if(update_option('flickrstream_main_opts', $opts))
						echo '<div class="updated"><p>Settings saved.</p></div>'; 
					else
						echo '<div class="error"><p>Oops... something went wrong or there were no changes needed</p></div>';
						
				}
						
			}
			//SAVE NEW SHORTCODE//
			elseif(isset($_POST['saveShortcode']))
			{
				
				if(check_admin_referer('flickrstream_save_shortcode'))
				{
										
					$optname = 'flickrstream_short_' . $this->_options['marker'];
							
					$ins['vanityname'] = sanitize_text_field($_POST['vanityname']);
					$ins['type'] = sanitize_text_field($_POST['type']);
					$ins['id'] = sanitize_text_field($_POST['id']);
					$ins['photocnt'] = sanitize_text_field($_POST['photocnt']);
					$ins['photoselect'] = sanitize_text_field($_POST['photoselect']);
					$ins['linktype'] = sanitize_text_field($_POST['linktype']);
					$ins['thumbsize'] = sanitize_text_field($_POST['thumbsize']);
					$ins['photoAlign'] = sanitize_text_field($_POST['photoAlign']);	
					$ins['cachedata'] = (isset($_POST['cachedata']) ? 'on' : 'off');	
					$ins['hidetitle'] = (isset($_POST['hidetitle']) ? 'on' : 'off');
					$ins['hidecaption'] = (isset($_POST['hidecaption']) ? 'on' : 'off');	
					$ins['shortid'] = $this->_options['marker'];
					$ins['updated'] = current_time('timestamp');
							
					if($ins['cachedata'] == 'on' && $ins['photocnt'])
					{
							
						require 'fsworkhorse.class.php';
						$fs = new fsWorkhorse();
						$ins['cache'] = $fs->returnCache($ins);
												
					}
							
					$this->_options['marker']++;	
					update_option('flickrstream_main_opts', $this->_options);		
					
					if(update_option($optname, $ins))
						echo '<div class="updated"><p>Shortcode created.</p></div>';
					else
						echo '<div class="error"><p>Oops... something went wrong</p></div>';
					
				}
							
			}
			//UPDATE A SHORTCODE//
			elseif(isset($_POST['updateShortcode']))
			{
			
				if(check_admin_referer('flickrstream_update_shortcode'))
				{
			
					$ins['vanityname'] = sanitize_text_field($_POST['vanityname']);
					$ins['type'] = sanitize_text_field($_POST['type']);
					$ins['id'] = sanitize_text_field($_POST['id']);
					$ins['photocnt'] = sanitize_text_field($_POST['photocnt']);
					$ins['photoselect'] = sanitize_text_field($_POST['photoselect']);
					$ins['linktype'] = sanitize_text_field($_POST['linktype']);
					$ins['thumbsize'] = sanitize_text_field($_POST['thumbsize']);
					$ins['photoAlign'] = sanitize_text_field($_POST['photoAlign']);
					$ins['cachedata'] = (isset($_POST['cachedata']) ? 'on' : 'off');	
					$ins['hidetitle'] = (isset($_POST['hidetitle']) ? 'on' : 'off');
					$ins['hidecaption'] = (isset($_POST['hidecaption']) ? 'on' : 'off');	
					$ins['shortid'] = sanitize_text_field($_POST['shortid']);
					$ins['updated'] = current_time('timestamp');
					$optname = 'flickrstream_short_' . $ins['shortid'];
							
					if($ins['cachedata'] == 'on' && $ins['photocnt'])
					{
							
						require 'fsworkhorse.class.php';
						$fs = new fsWorkhorse();
						$ins['cache'] = $fs->returnCache($ins);
									
					}
							
					if(update_option($optname, $ins))
						echo '<div class="updated"><p>Shortcode updated.</p></div>';
					else
						echo '<div class="error"><p>Oops... something went wrong</p></div>';
					
				}
				
			}
			//DELETE A SHORTCODE//
			elseif(isset($_POST['delShortcode']))
			{
				
				if(check_admin_referer('flickrstream_actions'))
				{
			
					if(delete_option('flickrstream_short_' . $_POST['key']))
						echo '<div class="updated"><p>Shortcode deleted.</p></div>';
					
				}
				
			}
			
		}
			
	}
}
?>