<?php 
/**
 * Flickrstream_Widget - Photo widget for Flickr-stream
 *
 * @package Flickr-stream
 * @author Dustin Scarberry
 *
 * @since 1.1.5
 */
class Flickrstream_Widget extends WP_Widget {

	//constructor
	public function __construct() {
		parent::__construct(
	 		'flickrstream_widget', // Base ID
			'Flickrstream', // Name
			array('description' => __('Display a Flickr photoset or gallery')) // Args
		);
	}

	//display widget frontend
	public function widget($args, $ins)	
	{
		
		extract($args);
		require_once 'fsworkhorse.class.php';
		
		echo $before_widget . '<div id="flickrstream_widgetbox">';
		
		$workhorse = new fsWorkhorse();
		echo $workhorse->returnPhotos('widget', $ins, $args);
		
		echo '</div>' . $after_widget;
		
	}
	
	//process widget updates
	public function update($new, $old) 
	{
		
		$ins['id'] = sanitize_text_field($new['id']);	
		$ins['type'] = sanitize_text_field($new['type']);	
		$ins['photocnt'] = sanitize_text_field($new['photocnt']);	
		$ins['photoselect'] = sanitize_text_field($new['photoselect']);
		$ins['linktype'] = sanitize_text_field($new['linktype']);	
		$ins['hidetitle'] = (isset($new['hidetitle']) ? 'on' : 'off');
		$ins['hidecaption'] = (isset($new['hidecaption']) ? 'on' : 'off');
		$ins['cachedata'] = (isset($new['cachedata']) ? 'on' : 'off');
	
		if($ins['cachedata'] == 'on')
		{
		
			if($ins['photocnt'])
			{
			
				require 'fsworkhorse.class.php';
				$fs = new fsWorkhorse();
				$ins['cache'] = $fs->returnCache($ins);
				
			}
		
		}
		
		return $ins;
		
	}

	//display widget control form
	public function form($ins) 
	{
		
	?>	
	
	<div id="flickrstream_widget_controls">
		<label>Type:</label>
		<select name="<?php echo $this->get_field_name('type'); ?>">
			<option></option>			

			<?php						
		
			$opts = array(0 => 'Gallery', 1 => 'Set');	
		
			foreach($opts as $value)			
			{				
				if($value == $ins['type'])	
					echo '<option selected>' . $value . '</option>';
				else					
					echo '<option>' . $value . '</option>';		
			}							
		
			?>					
		
		</select>			
		<label>ID:</label>	
		<input type="text" name="<?php echo $this->get_field_name('id'); ?>" value="<?php echo esc_attr($ins['id']); ?>"/>	
		<label># Of Photos:</label>	
		<select name="<?php echo $this->get_field_name('photocnt'); ?>">
			<option></option>				

			<?php
			
			for($i = 1; $i < 11; $i++)			
			{				
			
				if($i == $ins['photocnt'])
					echo '<option selected>' . $i . '</option>';
				else				
					echo '<option>' . $i . '</option>';	
					
			}
			
			?>	

		</select>		
		<label>Photo Selection:</label>		
		<select name="<?php echo $this->get_field_name('photoselect'); ?>">
			<option></option>						
			
			<?php						
			
			$opts = array(0 => 'Beginning', 1 => 'Random');	

			foreach($opts as $value)
			{				
			
				if($value == $ins['photoselect'])
					echo '<option selected>' . $value . '</option>';
				else					
					echo '<option>' . $value . '</option>';
					
			}
			
			?>
			
		</select>
		<label>Link Type:</label>	
		<select name="<?php echo $this->get_field_name('linktype'); ?>">
			<option></option>					

			<?php					

			$opts = array(0 => 'Image/Fancybox', 1 => 'Flickr');	

			foreach($opts as $value)			
			{
			
				if($value == $ins['linktype'])	
					echo '<option selected>' . $value . '</option>';		
				else					
					echo '<option>' . $value . '</option>';		
			
			}
			
			?>	
			
		</select>		
		<div class="toggleOptions">		
			
			<?php				
				
			if($ins['hidetitle'] == 'on')			
				echo '<input type="checkbox" name="' . $this->get_field_name('hidetitle') . '" checked/>';	
			else			
				echo '<input type="checkbox" name="' . $this->get_field_name('hidetitle') . '"/>';				

			?>	
			
			<label class="inline">Hide Gallery/Set Title</label><br/>		
		
			<?php
			
			if($ins['cachedata'] == 'on')
				echo '<input type="checkbox" name="' . $this->get_field_name('cachedata') . '" checked/>';	
			else
				echo '<input type="checkbox" name="' . $this->get_field_name('cachedata') . '"/>';
						
			?>
			
			<label class="inline">Cache Data</label><br/>
			
			<?php				
				
			if($ins['hidecaption'] == 'on')			
				echo '<input type="checkbox" name="' . $this->get_field_name('hidecaption') . '" checked/>';	
			else			
				echo '<input type="checkbox" name="' . $this->get_field_name('hidecaption') . '"/>';				

			?>
			
			<label class="inline">Hide Captions</label>
			
		</div>	
	</div>		
		
	<?php 
	
	}

}

?>